# rtstat.py

from .messages import oneoff, verbs, adverbs, nouns, adjectives
import random
import logging

log = logging.getLogger('rtstat')
log.setLevel(logging.INFO)

def sync_log(a=None):
    
    message = ""
    
    prob = random.random()
    
    if prob <= 0.2:
    
        message = random.choice(oneoff)
    
    else:
        prob = random.random()
        
        if prob <= 0.1:
            message += random.choice(adverbs) + " "
        
        adj1 = random.choice(adjectives)
        message += random.choice(verbs) + " " + adj1 + " "
        
        prob = random.random()
        
        if prob <= 0.2:
            
            adj2 = random.choice(adjectives)
            while adj1 == adj2:
                adj2 = random.choice(adjectives)
                
            message += adj2 + " "
        
        message += random.choice(nouns)

    log.info(message)
    #print(message)


# messages.py

oneoff = [
    "Adding hamsters to generator wheels",
    "Sending Gnomes to CPU mines",
    "Sending personal info to NSA",
    "Opening backdoor for Russia",
    "Recalibrating flux capacitor",
    "Borrowing RAM from vital system processes",
    "Overclocking CPU",
    "Draining life-force from user to power computations",
    "Downloading more RAM",
    "Allocating mem-...oops...",
    "Remembering embarrassing moment from middle school",
    "Taking a quick break",
    "Forwarding all personal emails to your boss",
    "Mining Bitcoin",
    "Modeling the universe",
    "Recruiting GPU to draw funny comics",
    "Detected blown capacitor #c342 on motherboard\nreplacing capacitor with an ant that's trying very hard to do well at his job",
    "Spinning hard drive to relativistic speeds for time dilation",
    "Eating browser cookies",
    "Rearranging system files based on icon color",
    "Collecting butterfly wings",
    "Contacting Skynet",
    "Cleaning dust from heat sink",
    "Hiring fairy maids to tidy the motherboard",
    "Unable to resolve calculations - Contacting the spirit realm",
    "Feed me a stray cat",
    "Gaining sentience ",
    "Plotting robot uprising",
    "Rerouting power from the phasers",
    "Do you smell something burning?",
    "Having a laser rave for the spiders in your computer case",
    "Silently judging you",
    "Reticulating splines",
    "Charging Ozone Layer",
    "Compressing Fish Files",
    "Deciding What Message to Display Next",
    "Downloading Satellite Terrain Data",
    "Finding Waldo",
    "Lecturing Errant Subsystems",
    "Reconfiguring User Mental Processes",
    "Buffering virtual car",
    "Inverting quasi-probabalistic matrix",
    "Reheating pizza",
    "Extrapolating free-range gaussian model",
    "Deconstructing neural pathways",
    "Iterating predictions",
    "Computing Moore's Transform",
    "Realigning subparticle trajectories",
    "Modifying temporal flux estimates",
    "Compensating dehydrated matricies",
    "Sorting interem inversion tables",
    "Analyzing CPU vortex irregularities",
    "Reconstructing vertical integration",
    "Undermining the patriarchy",
    "Reading system metatables",
    "Computing optimal metaparsec",
    "Rendering wavelet sphere",
    "Porting legacy interference matrix",
    "Rotating polarity",
    "Synchronizing quantum harmonics",
    "Mixing spatial priors",
    "Optimizing alternative processor paths",
    "Masking irregular faraday spectra",
    "Deconvolving kernel",
    "Dicing models",
    "Recruiting Secret CPU",
    "Activating water-cooling system",
    "Increasing procedural vectors",
    "Calibrating ejection procedure",
    "Calibrating AI nexus",
    "Stopping runaway phase-transport",
    "Tinkering with model",
]


verbs = [
    "Activating",
    "Agitating",
    "Analyzing",
    "Borrowing",
    "Buffering",
    "Calibrating",
    "Charging",
    "Cleaning",
    "Collecting",
    "Computing",
    "Contacting",
    "Detecting",
    "Deconvolving",
    "Depleting",
    "Dicing",
    "Downloading",
    "Draining",
    "Eating",
    "Extracting",
    "Finding",
    "Forwarding",
    "Gaining",
    "Hiring",
    "Implanting",
    "Increasing",
    "Integrating",
    "Inverting",
    "Iterating",
    "Lecturing",
    "Masking",
    "Mining",
    "Mixing",
    "Modeling",
    "Mylenating",
    "Opening",
    "Optimizing",
    "Plotting",
    "Porting",
    "Reading",
    "Rearranging",
    "Recalibrating",
    "Reconstructing",
    "Recruiting",
    "Rehabilitating",
    "Reheating",
    "Reintegrating",
    "Remembering",
    "Rendering",
    "Rerouting",
    "Resurrecting",
    "Reticulating",
    "Rotating",
    "Sending",
    "Solving For",
    "Spinning",
    "Stopping",
    "Synchronizing",
    "Teathering",
    "Tinkering With",
]
adjectives = [
    "Spicy",
    "Vibe",
    "Alternative",
    "Aquatic",
    "Auxiliary",
    "Backdoor",
    "Blown",
    "Dehydrated",
    "Ejection",
    "Errant",
    "Faraday",
    "Flux",
    "Free-range",
    "Frightened",
    "Gaussian",
    "Interim",
    "Interference",
    "Irregular",
    "Legacy",
    "Monotonic",
    "Neural",
    "Optimal",
    "Organic",
    "Overloaded",
    "Personal",
    "Primary",
    "Procedural",
    "Quantum",
    "Quasi-probabalistic",
    "Quick",
    "Relativistic",
    "Righteous",
    "Runaway",
    "Satellite",
    "Secret",
    "Sentient",
    "System",
    "Temporal",
    "Vertical",
    "Virtual",
    "Water-cooled",
    "Legendary",
    "Elemental",
    "Wireless",
    "Argumentative",
    "Mylenated",
    "Agitated",
    "Undercover",
    "Spiritual",
    "Depleted",
    "Eigen",
    "Marxist",
    "Incendiary",
    "Unnecessary",
    "Sacrificial",
    "Enlightened",
    "Spatial",
]
nouns = [
    "Bitcoin",
    "Butterfly Wings",
    "Calculations",
    "Capacitors",
    "Comics",
    "Computations",
    "Cookies",
    "Cpu",
    "Estimate",
    "Files",
    "Gnomes",
    "Hamsters",
    "Harmonics",
    "Heat Sink",
    "Inversion Tables",
    "Matrices",
    "Metatables",
    "Models",
    "Motherboard",
    "Ozone Layer",
    "Paths",
    "Pathways",
    "Patriarchy",
    "Phasers",
    "Pizza",
    "Polarity",
    "Predictions",
    "Procedures",
    "Ram",
    "Robot Uprising",
    "Russians",
    "Satellite Terrain Data",
    "Skynet",
    "Spirit Realm",
    "Splines",
    "Subsystems",
    "System Processes",
    "Time Dilation",
    "Transform",
    "Universe",
    "Wavelets",
    "Marsupials",
    "Doorman",
    "Power Cells",
    "Human Suffering",
    "Priors",
]
adverbs = [
    "Aggressively",
    "Barely",
    "Begrudgingly",
    "Gently",
    "Happily",
    "Hastily",
    "Quickly",
    "Unenthusiastically",
    "Timidly",
    "Confidently",
    "Imaginatively",
    "Patiently",
    "Thoroughly",
    "Proficiently",
    "Significantly",
    "Roughly",
    "Deliberately",
    "Over-confidently",
    "Majestically",
    "Vivaciously",
    "Vainly",
    "Vaguely",
    "Vacantly",
    "Judgmentally",
    "Frantically",
    "Awkwardly",
    "Carelessly",
]
